@@ -6,10 +6,12 @@ __email__ = 'info@3liz.org'
 
 
 class Plugin(NamedTuple):
+    """ Definition of a plugin in the XML file. """
     name: str = None
     description: str = None
     version: str = None
     qgis_minimum_version: str = None
+    qgis_maximum_version: str = None
     homepage: str = None
     prerelease: str = None
     file_name: str = None
@@ -24,3 +26,11 @@ class Plugin(NamedTuple):
     tracker: str = None
     repository: str = None
     tags: str = None
+
+
+class Level:
+    """ Color in terminal. """
+    Success = '\033[92m'
+    Warning = '\033[93m'
+    Critical = '\033[91m'
+    End = '\033[0m'
