@@ -9,37 +9,75 @@ import urllib.request
 import xml.etree.ElementTree as ET
 
 from pathlib import Path
+from typing import Union
 
-from qgis_plugin_manager.definitions import Plugin
+from qgis_plugin_manager.definitions import Level, Plugin
+from qgis_plugin_manager.utils import qgis_server_version, DEFAULT_QGIS_VERSION
 
 
 class Remote:
 
     def __init__(self, folder: Path):
+        """ Constructor. """
         self.folder = folder
         self.list = None
         self.list_plugins = None
 
     def remote_list(self) -> list:
+        """Return the list of remotes configured.
+
+        The token [VERSION] is replaced by the current version X.YY
+        """
         self.list = []
         source_list = Path(self.folder / 'sources.list')
         if not source_list.exists():
             return []
 
+        qgis_version = qgis_server_version()
+        if not qgis_version:
+            qgis_version = DEFAULT_QGIS_VERSION
+
+        qgis_version = qgis_version.split('.')
+
         with source_list.open() as f:
             for line in f.readlines():
                 if not line.startswith('#'):
-                    self.list.append(line.strip())
+                    raw_line = line.strip()
+                    if raw_line.startswith("https://plugins.qgis.org") and "[VERSION]" not in raw_line:
+                        print(
+                            f"{Level.Warning}"
+                            f"Your https://plugins.qgis.org remote is not using dynamic QGIS version."
+                            f"{Level.End}"
+                        )
+                        print(
+                            f"Instead of\n{raw_line}"
+                            f"\n"
+                            f"you should have"
+                            f"\n"
+                            f"https://plugins.qgis.org/plugins/plugins.xml?qgis=[VERSION]"
+                            f"\n"
+                            f"If you can remove the file sources.list ? 'qgis-plugin-manager init' will "
+                            f"regenerate it using dynamic QGIS version."
+                        )
+
+                    raw_line = raw_line.replace("[VERSION]", f"{qgis_version[0]}.{qgis_version[1]}")
+                    self.list.append(raw_line)
+
         return self.list
 
     def print_list(self):
+        """ Print in the console the list of remotes. """
         if self.list is None:
             self.remote_list()
 
         print("List of remotes :\n")
-        print('\n'.join(self.list))
+        if len(self.list):
+            print('\n'.join(self.list))
+        else:
+            print(f"{Level.Warning}No remote configured{Level.End}")
 
     def update(self):
+        """ For each remote, it updates the XML file. """
         if self.list is None:
             self.remote_list()
 
@@ -68,9 +106,11 @@ class Remote:
             with open(Path(cache / f"{filename}.xml"), 'wb') as output:
                 output.write(f.read())
 
-            print("\tOk")
+            print(f"\t{Level.Success}Ok{Level.End}")
 
-    def latest(self, plugin_name):
+    def latest(self, plugin_name: str) -> Union[str, None]:
+        """ For a given plugin, it returns the latest version found in all remotes. """
+        # plugins is a dict : plugin_name : version
         plugins = {}
         self.list_plugins = {}
 
@@ -115,20 +155,27 @@ class Remote:
                     if element.tag in plugin_obj._fields:
                         data[element.tag] = element.text
 
+                # Not present in XML, but property available in metadata.txt
+                data['qgis_maximum_version'] = ''
+
                 plugin_obj = Plugin(**data)
                 self.list_plugins[xml_plugin_name] = plugin_obj
 
         if not has_xml:
-            print("No remote repositories found !")
+            print(f"{Level.Warning}No remote repositories found !{Level.End}")
             return None
 
         return plugins.get(plugin_name)
 
-    def install(self, plugin_name, version="latest"):
+    def install(self, plugin_name, version="latest") -> bool:
+        """ Install the plugin with a specific version.
+
+        Default version is latest.
+        """
         xml_version = self.latest(plugin_name)
         if xml_version is None:
-            print(f"Plugin {plugin_name} {version} not found.")
-            return
+            print(f"{Level.Warning}Plugin {plugin_name} {version} not found.{Level.End}")
+            return False
 
         print(f"Installation {plugin_name} {version}")
 
@@ -144,8 +191,8 @@ class Remote:
         try:
             f = urllib.request.urlopen(request)
         except urllib.error.HTTPError:
-            print(f"Plugin {plugin_name} {version} not found.")
-            return
+            print(f"{Level.Warning}Plugin {plugin_name} {version} not found.{Level.End}")
+            return False
 
         zip_file = Path(self.folder / file_name)
         with open(zip_file, 'wb') as output:
@@ -161,6 +208,6 @@ class Remote:
 
         zip_file.unlink()
 
-        print(f"\tOk {zip_file.name}")
+        print(f"\t{Level.Success}Ok {zip_file.name}{Level.End}")
 
-        return 0
+        return True
