@@ -4,8 +4,12 @@ __email__ = 'info@3liz.org'
 
 from typing import Union
 
+from qgis_plugin_manager.definitions import Level
 
-def pretty_table(iterable, header):
+DEFAULT_QGIS_VERSION = "3.16"
+
+
+def pretty_table(iterable, header) -> str:
     """ Copy/paste from http://stackoverflow.com/a/40426743/2395485 """
     max_len = [len(x) for x in header]
     for row in iterable:
@@ -38,9 +42,9 @@ def parse_version(version: str) -> Union[None, list]:
     return version
 
 
-def qgis_server_version():
-    """ Try to guess the QGIS Server version. 
-    
+def qgis_server_version() -> str:
+    """ Try to guess the QGIS Server version.
+
         On linux distro, qgis python packages are installed at standard location
         in /usr/lib/python3/dist-packages
     """
@@ -48,4 +52,9 @@ def qgis_server_version():
         from qgis.core import Qgis
         return Qgis.QGIS_VERSION.split('-')[0]
     except ImportError:
-        print("Cannot check version with PyQGIS, check your QGIS installation or your PYTHONPATH")
+        print(
+            f"{Level.Warning}"
+            f"Cannot check version with PyQGIS, check your QGIS installation or your PYTHONPATH"
+            f"{Level.End}"
+        )
+    return ''
