@@ -9,7 +9,7 @@ from pathlib import Path
 from qgis_plugin_manager.local_directory import LocalDirectory
 
 
-class PluginManager(unittest.TestCase):
+class TestLocal(unittest.TestCase):
 
     def setUp(self) -> None:
         self.local = LocalDirectory(Path('fixtures/plugins'))
@@ -20,6 +20,7 @@ class PluginManager(unittest.TestCase):
         self.assertCountEqual(['missing_init', 'missing_metadata'], self.local.invalid)
 
     def test_read_metadata(self):
+        """ Test read metadata. """
         self.assertIsNone(self.local.plugin_metadata('do_not_exist', 'author'))
         self.assertIsNone(self.local.plugin_metadata('missing_init', 'author'))
         self.assertIsNone(self.local.plugin_metadata('missing_metadata', 'author'))
@@ -27,9 +28,13 @@ class PluginManager(unittest.TestCase):
         self.assertEqual('Hazel Nutt', self.local.plugin_metadata('plugin_a', 'author'))
         self.assertEqual('', self.local.plugin_metadata('plugin_a', 'do_not_exist'))
 
-        self.assertCountEqual(
-            ['Plugin A', '1.0.0', '', '3.0', '', 'Hazel Nutt'],
-            self.local.plugin_all_info('plugin_a'))
+        plugin = self.local.plugin_info('plugin_a')
+        self.assertEqual('Plugin A', plugin.name)
+        self.assertEqual('1.0.0', plugin.version)
+        self.assertEqual('', plugin.experimental)
+        self.assertEqual('3.0', plugin.qgis_minimum_version)
+        self.assertEqual('', plugin.qgis_maximum_version)
+        self.assertEqual('Hazel Nutt', plugin.author_name)
 
 
 if __name__ == '__main__':
