@@ -9,17 +9,17 @@ from pathlib import Path
 from qgis_plugin_manager.remote import Remote
 
 
-class PluginManager(unittest.TestCase):
-
-    def setUp(self) -> None:
-        self.remote = Remote(Path('fixtures/plugins'))
+class TestRemote(unittest.TestCase):
 
     def test_list_remote(self):
+        """ Test read the sources.list file. """
+        self.remote = Remote(Path('fixtures/plugins'))
         self.assertCountEqual(
             ["https://my.url/plugins.xml", "https://my.repo/plugins.xml"],
             self.remote.remote_list())
 
     @unittest.expectedFailure
     def test_latest_pgmetadata(self):
+        """ Test read multiple remotes. """
         # There is 0.1.0 and 0.2.0 in these XML files
         self.assertEqual('0.2.0', self.remote.latest("PgMetadata"))
